Title
=====

This is a normal sentence. This sentence is on the same line.
This sentence is on the next line.

Formatting
----------
This is also a normal sentence.
This one has some ``literals`` mixed in for ``fun``. This one has some *italic* text and **bold** text.

More Formatting
---------------
*This one* starts with formatting **and then has more**

This line has a raw asterisk \* in it.
This bit has a raw asterisk \* and another \* and then some ``literals``. It's also fun.

Links
-----

Here is a sentence with a `link <https://www.python.org/>`_.
